/*****************************************************************************
  *                                                                           
  *  Copyright (c) 2008 Johannes Hermen www.der-frickler.net                   
  *                                                                           
  *                                                                           
  *  This library is free software; you can redistribute it and/or modify it  
  *  under the terms of the GNU Lesser General Public License as published    
  *  by the Free Software Foundation; either version 2 of the License, or     
  *  (at your option) any later version.                                      
  *                                                                           
  *  This software is distributed in the hope that it will be useful, but     
  *  WITHOUT ANY WARRANTY; without even the implied warranty of               
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        
  *  Lesser General Public License for more details.                          
  *                                                                           
  *  You should have received a copy of the GNU Lesser General Public         
  *  License along with this library; if not, write to the Free Software      
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA  
  *                                                                           
  *****************************************************************************
  *                                                                           
  *  MEGA8 Light Module
  *  switches the different lights on dependent to the stick position .        
  *                                                                           
  *  PINOUT: Servo Signal IN: PIN 4 (INT0)                                     
  *         PB1-PB3 position light
  *         PB4-PB5 single-flashing light (red)
  *         PB6-PB7 double-flashing light (white)
  *         PD0-PD7 (except PD2/INT0) landing light
  *                                                                           
  *****************************************************************************/


#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>

uint16_t value;

// on timer1 overflow
ISR (TIM1_OVF_vect)	
{
	value = 2000;
}

// on INT0 / PD2 pinchange
ISR (INT0_vect)
{
  if ((PIND & 4)==4) 	// check 3th bit of PORTD (pin 4) got HIGH
  {
 	TCCR1B = 0;			// stop timer1
    TCNT1 = 0; 			// reset timer1 
    TCCR1B = 1;			// start 16bit timer1 - no prescale
  }
  else {	// check 3th bit of PORTD (pin 4) got LOW

	TCCR1B = 0; 		// stop timer1
	value = TCNT1;     // get Timer Value
	TCCR1B = 1;		   // start timer1
  }
}

int main (void)
{

  	DDRB = 255;	// portb as output
	PORTB = 0; 	// portb to 0	

  	DDRD = 251;	// portd as output, int0 as input 
	PORTD = 0; 	// portd to 0	

    DDRC = 0;    // portc as input
    PORTC = 255; // portc to 0

    MCUCR = 1;	// External Interrupt on PinChange
    GICR = 64;	// enable Int0

    TCNT1 = 0;

    TIMSK = 1;												// 16-Bit Timer Overflow-Interrupt an
    TCCR1A = 0;												// 16-Bit Normal Mode
    TCCR1B = 0;												// stop 16-Bit Timer 


  	sei(); 	// Interrupts on.

	uint16_t j; // define a wait counter variable

	TCCR1B = 1;		   // start timer1


	while(1)
	{
		if (value > 1800) { 
			PORTD = 224;
		} else {
			PORTD = 0;
		} if (value > 1400) { 
			PORTB = 207;     // position+whiteflash pins on
			j=3000;
        	while(0<j--);       // wait "on" time
			PORTB = 15;      // flash pins (white) off
			j=3000;
        	while(0<j--);        // wait "off" time
			PORTB = 207;     // flash pins (white) on
			j=3000;
        	while(0<j--);        // wait "on" time
			PORTB = 15;       // flash pins (white) off
			j=50000;            
//			j=10000;            
        	while(0<j--);        // wait for next flash
        	PORTB = 63;       // flash pins (red) on
            j=3000;
            while(0<j--);         // wait "on" time
            PORTB = 15;        // flash pins (red) off
//        	j=50000;            
			j=50000;            
            while(0<j--);         // wait for next flash
		} else 
		if (value > 800) { 
			PORTB = 15;     // both pins on
		}  else {  			// set port to 0
			PORTB = 0;
		}
	}
}
